/*********************************************************************
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2024, PickNik Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of PickNik Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *********************************************************************/

/* Author: Sebastian Jahr
   Description: List of all parameter names used when move_group with OMPL, CHOMP, STOMP and PILZ is launched (01/2024).
*/

#pragma once

#include <string>

namespace move_group_test
{
const std::vector<std::string> PARAMETER_NAME_LIST = {
  "chomp.add_randomness",
  "chomp.animate_endeffector",
  "chomp.animate_endeffector_segment",
  "chomp.animate_path",
  "chomp.collision_clearance",
  "chomp.collision_threshold",
  "chomp.default_workspace_bounds",
  "chomp.display_contacts_topic",
  "chomp.display_path_topic",
  "chomp.enable_failure_recovery",
  "chomp.fix_start_state",
  "chomp.hmc_annealing_factor",
  "chomp.hmc_discretization",
  "chomp.hmc_stochasticity",
  "chomp.joint_update_limit",
  "chomp.learning_rate",
  "chomp.max_iterations",
  "chomp.max_iterations_after_collision_free",
  "chomp.max_recovery_attempts",
  "chomp.obstacle_cost_weight",
  "chomp.planning_plugins",
  "chomp.planning_time_limit",
  "chomp.progress_topic",
  "chomp.pseudo_inverse_ridge_factor",
  "chomp.random_jump_amount",
  "chomp.request_adapters",
  "chomp.response_adapters",
  "chomp.ridge_factor",
  "chomp.smoothness_cost_acceleration",
  "chomp.smoothness_cost_jerk",
  "chomp.smoothness_cost_velocity",
  "chomp.smoothness_cost_weight",
  "chomp.totg.min_angle_change",
  "chomp.totg.path_tolerance",
  "chomp.totg.resample_dt",
  "chomp.trajectory_initialization_method",
  "chomp.use_hamiltonian_monte_carlo",
  "chomp.use_pseudo_inverse",
  "chomp.use_stochastic_descent",
  "default_planning_pipeline",
  "moveit_controller_manager",
  "moveit_manage_controllers",
  "moveit_simple_controller_manager.controller_names",
  "moveit_simple_controller_manager.panda_arm_controller.action_ns",
  "moveit_simple_controller_manager.panda_arm_controller.default",
  "moveit_simple_controller_manager.panda_arm_controller.joints",
  "moveit_simple_controller_manager.panda_arm_controller.type",
  "moveit_simple_controller_manager.panda_hand_controller.action_ns",
  "moveit_simple_controller_manager.panda_hand_controller.default",
  "moveit_simple_controller_manager.panda_hand_controller.joints",
  "moveit_simple_controller_manager.panda_hand_controller.type",
  "ompl.default_workspace_bounds",
  "ompl.display_contacts_topic",
  "ompl.display_path_topic",
  "ompl.fix_start_state",
  "ompl.hand.planner_configs",
  "ompl.panda_arm.planner_configs",
  "ompl.panda_arm_hand.planner_configs",
  "ompl.planner_configs.APSConfigDefault.hybridize",
  "ompl.planner_configs.APSConfigDefault.max_hybrid_paths",
  "ompl.planner_configs.APSConfigDefault.num_planners",
  "ompl.planner_configs.APSConfigDefault.planners",
  "ompl.planner_configs.APSConfigDefault.shortcut",
  "ompl.planner_configs.APSConfigDefault.type",
  "ompl.planner_configs.BFMTkConfigDefault.balanced",
  "ompl.planner_configs.BFMTkConfigDefault.cache_cc",
  "ompl.planner_configs.BFMTkConfigDefault.extended_fmt",
  "ompl.planner_configs.BFMTkConfigDefault.heuristics",
  "ompl.planner_configs.BFMTkConfigDefault.nearest_k",
  "ompl.planner_configs.BFMTkConfigDefault.num_samples",
  "ompl.planner_configs.BFMTkConfigDefault.optimality",
  "ompl.planner_configs.BFMTkConfigDefault.radius_multiplier",
  "ompl.planner_configs.BFMTkConfigDefault.type",
  "ompl.planner_configs.BKPIECEkConfigDefault.border_fraction",
  "ompl.planner_configs.BKPIECEkConfigDefault.failed_expansion_score_factor",
  "ompl.planner_configs.BKPIECEkConfigDefault.min_valid_path_fraction",
  "ompl.planner_configs.BKPIECEkConfigDefault.range",
  "ompl.planner_configs.BKPIECEkConfigDefault.type",
  "ompl.planner_configs.BiESTkConfigDefault.range",
  "ompl.planner_configs.BiESTkConfigDefault.type",
  "ompl.planner_configs.BiTRRTkConfigDefault.cost_threshold",
  "ompl.planner_configs.BiTRRTkConfigDefault.frountier_node_ratio",
  "ompl.planner_configs.BiTRRTkConfigDefault.frountier_threshold",
  "ompl.planner_configs.BiTRRTkConfigDefault.init_temperature",
  "ompl.planner_configs.BiTRRTkConfigDefault.range",
  "ompl.planner_configs.BiTRRTkConfigDefault.temp_change_factor",
  "ompl.planner_configs.BiTRRTkConfigDefault.type",
  "ompl.planner_configs.ESTkConfigDefault.goal_bias",
  "ompl.planner_configs.ESTkConfigDefault.range",
  "ompl.planner_configs.ESTkConfigDefault.type",
  "ompl.planner_configs.FMTkConfigDefault.cache_cc",
  "ompl.planner_configs.FMTkConfigDefault.extended_fmt",
  "ompl.planner_configs.FMTkConfigDefault.heuristics",
  "ompl.planner_configs.FMTkConfigDefault.nearest_k",
  "ompl.planner_configs.FMTkConfigDefault.num_samples",
  "ompl.planner_configs.FMTkConfigDefault.radius_multiplier",
  "ompl.planner_configs.FMTkConfigDefault.type",
  "ompl.planner_configs.KPIECEkConfigDefault.border_fraction",
  "ompl.planner_configs.KPIECEkConfigDefault.failed_expansion_score_factor",
  "ompl.planner_configs.KPIECEkConfigDefault.goal_bias",
  "ompl.planner_configs.KPIECEkConfigDefault.min_valid_path_fraction",
  "ompl.planner_configs.KPIECEkConfigDefault.range",
  "ompl.planner_configs.KPIECEkConfigDefault.type",
  "ompl.planner_configs.LBKPIECEkConfigDefault.border_fraction",
  "ompl.planner_configs.LBKPIECEkConfigDefault.min_valid_path_fraction",
  "ompl.planner_configs.LBKPIECEkConfigDefault.range",
  "ompl.planner_configs.LBKPIECEkConfigDefault.type",
  "ompl.planner_configs.LBTRRTkConfigDefault.epsilon",
  "ompl.planner_configs.LBTRRTkConfigDefault.goal_bias",
  "ompl.planner_configs.LBTRRTkConfigDefault.range",
  "ompl.planner_configs.LBTRRTkConfigDefault.type",
  "ompl.planner_configs.LazyPRMkConfigDefault.range",
  "ompl.planner_configs.LazyPRMkConfigDefault.type",
  "ompl.planner_configs.LazyPRMstarkConfigDefault.type",
  "ompl.planner_configs.PDSTkConfigDefault.type",
  "ompl.planner_configs.PRMkConfigDefault.max_nearest_neighbors",
  "ompl.planner_configs.PRMkConfigDefault.type",
  "ompl.planner_configs.PRMstarkConfigDefault.type",
  "ompl.planner_configs.ProjESTkConfigDefault.goal_bias",
  "ompl.planner_configs.ProjESTkConfigDefault.range",
  "ompl.planner_configs.ProjESTkConfigDefault.type",
  "ompl.planner_configs.RRTConnectkConfigDefault.range",
  "ompl.planner_configs.RRTConnectkConfigDefault.type",
  "ompl.planner_configs.RRTkConfigDefault.goal_bias",
  "ompl.planner_configs.RRTkConfigDefault.range",
  "ompl.planner_configs.RRTkConfigDefault.type",
  "ompl.planner_configs.RRTstarkConfigDefault.delay_collision_checking",
  "ompl.planner_configs.RRTstarkConfigDefault.goal_bias",
  "ompl.planner_configs.RRTstarkConfigDefault.range",
  "ompl.planner_configs.RRTstarkConfigDefault.type",
  "ompl.planner_configs.SBLkConfigDefault.range",
  "ompl.planner_configs.SBLkConfigDefault.type",
  "ompl.planner_configs.SPARSkConfigDefault.dense_delta_fraction",
  "ompl.planner_configs.SPARSkConfigDefault.max_failures",
  "ompl.planner_configs.SPARSkConfigDefault.sparse_delta_fraction",
  "ompl.planner_configs.SPARSkConfigDefault.stretch_factor",
  "ompl.planner_configs.SPARSkConfigDefault.type",
  "ompl.planner_configs.SPARStwokConfigDefault.dense_delta_fraction",
  "ompl.planner_configs.SPARStwokConfigDefault.max_failures",
  "ompl.planner_configs.SPARStwokConfigDefault.sparse_delta_fraction",
  "ompl.planner_configs.SPARStwokConfigDefault.stretch_factor",
  "ompl.planner_configs.SPARStwokConfigDefault.type",
  "ompl.planner_configs.STRIDEkConfigDefault.degree",
  "ompl.planner_configs.STRIDEkConfigDefault.estimated_dimension",
  "ompl.planner_configs.STRIDEkConfigDefault.goal_bias",
  "ompl.planner_configs.STRIDEkConfigDefault.max_degree",
  "ompl.planner_configs.STRIDEkConfigDefault.max_pts_per_leaf",
  "ompl.planner_configs.STRIDEkConfigDefault.min_degree",
  "ompl.planner_configs.STRIDEkConfigDefault.min_valid_path_fraction",
  "ompl.planner_configs.STRIDEkConfigDefault.range",
  "ompl.planner_configs.STRIDEkConfigDefault.type",
  "ompl.planner_configs.STRIDEkConfigDefault.use_projected_distance",
  "ompl.planner_configs.TRRTkConfigDefault.frountierNodeRatio",
  "ompl.planner_configs.TRRTkConfigDefault.frountier_threshold",
  "ompl.planner_configs.TRRTkConfigDefault.goal_bias",
  "ompl.planner_configs.TRRTkConfigDefault.init_temperature",
  "ompl.planner_configs.TRRTkConfigDefault.k_constant",
  "ompl.planner_configs.TRRTkConfigDefault.max_states_failed",
  "ompl.planner_configs.TRRTkConfigDefault.min_temperature",
  "ompl.planner_configs.TRRTkConfigDefault.range",
  "ompl.planner_configs.TRRTkConfigDefault.temp_change_factor",
  "ompl.planner_configs.TRRTkConfigDefault.type",
  "ompl.planner_configs.TrajOptDefault.type",
  "ompl.planning_plugins",
  "ompl.progress_topic",
  "ompl.request_adapters",
  "ompl.response_adapters",
  "ompl.totg.min_angle_change",
  "ompl.totg.path_tolerance",
  "ompl.totg.resample_dt",
  "pilz_industrial_motion_planner.capabilities",
  "pilz_industrial_motion_planner.default_planner_config",
  "pilz_industrial_motion_planner.default_workspace_bounds",
  "pilz_industrial_motion_planner.fix_start_state",
  "pilz_industrial_motion_planner.planning_plugins",
  "pilz_industrial_motion_planner.progress_topic",
  "pilz_industrial_motion_planner.request_adapters",
  "pilz_industrial_motion_planner.response_adapters",
  "planning_pipelines",
  "publish_geometry_updates",
  "publish_planning_scene",
  "publish_robot_description",
  "publish_robot_description_semantic",
  "publish_state_updates",
  "publish_transforms_updates",
  "robot_description",
  "robot_description_kinematics.hand.kinematics_solver",
  "robot_description_kinematics.hand.kinematics_solver_search_resolution",
  "robot_description_kinematics.hand.kinematics_solver_timeout",
  "robot_description_kinematics.panda_arm.epsilon",
  "robot_description_kinematics.panda_arm.joints",
  "robot_description_kinematics.panda_arm.kinematics_solver",
  "robot_description_kinematics.panda_arm.kinematics_solver_search_resolution",
  "robot_description_kinematics.panda_arm.kinematics_solver_timeout",
  "robot_description_kinematics.panda_arm.max_solver_iterations",
  "robot_description_kinematics.panda_arm.orientation_vs_position",
  "robot_description_kinematics.panda_arm.position_only_ik",
  "robot_description_kinematics.panda_arm_hand.kinematics_solver",
  "robot_description_kinematics.panda_arm_hand.kinematics_solver_search_resolution",
  "robot_description_kinematics.panda_arm_hand.kinematics_solver_timeout",
  "robot_description_planning.cartesian_limits.max_rot_vel",
  "robot_description_planning.cartesian_limits.max_trans_acc",
  "robot_description_planning.cartesian_limits.max_trans_dec",
  "robot_description_planning.cartesian_limits.max_trans_vel",
  "robot_description_planning.joint_limits.panda_finger_joint1.angle_wraparound",
  "robot_description_planning.joint_limits.panda_finger_joint1.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_finger_joint1.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_finger_joint1.has_effort_limits",
  "robot_description_planning.joint_limits.panda_finger_joint1.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_finger_joint1.has_position_limits",
  "robot_description_planning.joint_limits.panda_finger_joint1.has_soft_limits",
  "robot_description_planning.joint_limits.panda_finger_joint1.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_finger_joint1.k_position",
  "robot_description_planning.joint_limits.panda_finger_joint1.k_velocity",
  "robot_description_planning.joint_limits.panda_finger_joint1.max_acceleration",
  "robot_description_planning.joint_limits.panda_finger_joint1.max_effort",
  "robot_description_planning.joint_limits.panda_finger_joint1.max_jerk",
  "robot_description_planning.joint_limits.panda_finger_joint1.max_position",
  "robot_description_planning.joint_limits.panda_finger_joint1.max_velocity",
  "robot_description_planning.joint_limits.panda_finger_joint1.min_position",
  "robot_description_planning.joint_limits.panda_finger_joint1.min_velocity",
  "robot_description_planning.joint_limits.panda_finger_joint1.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_finger_joint1.soft_upper_limit",
  "robot_description_planning.joint_limits.panda_finger_joint2.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_finger_joint2.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_finger_joint2.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_finger_joint2.max_acceleration",
  "robot_description_planning.joint_limits.panda_finger_joint2.max_position",
  "robot_description_planning.joint_limits.panda_finger_joint2.max_velocity",
  "robot_description_planning.joint_limits.panda_finger_joint2.min_position",
  "robot_description_planning.joint_limits.panda_joint1.angle_wraparound",
  "robot_description_planning.joint_limits.panda_joint1.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_joint1.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_joint1.has_effort_limits",
  "robot_description_planning.joint_limits.panda_joint1.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_joint1.has_position_limits",
  "robot_description_planning.joint_limits.panda_joint1.has_soft_limits",
  "robot_description_planning.joint_limits.panda_joint1.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_joint1.k_position",
  "robot_description_planning.joint_limits.panda_joint1.k_velocity",
  "robot_description_planning.joint_limits.panda_joint1.max_acceleration",
  "robot_description_planning.joint_limits.panda_joint1.max_effort",
  "robot_description_planning.joint_limits.panda_joint1.max_jerk",
  "robot_description_planning.joint_limits.panda_joint1.max_position",
  "robot_description_planning.joint_limits.panda_joint1.max_velocity",
  "robot_description_planning.joint_limits.panda_joint1.min_position",
  "robot_description_planning.joint_limits.panda_joint1.min_velocity",
  "robot_description_planning.joint_limits.panda_joint1.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_joint1.soft_upper_limit",
  "robot_description_planning.joint_limits.panda_joint2.angle_wraparound",
  "robot_description_planning.joint_limits.panda_joint2.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_joint2.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_joint2.has_effort_limits",
  "robot_description_planning.joint_limits.panda_joint2.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_joint2.has_position_limits",
  "robot_description_planning.joint_limits.panda_joint2.has_soft_limits",
  "robot_description_planning.joint_limits.panda_joint2.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_joint2.k_position",
  "robot_description_planning.joint_limits.panda_joint2.k_velocity",
  "robot_description_planning.joint_limits.panda_joint2.max_acceleration",
  "robot_description_planning.joint_limits.panda_joint2.max_effort",
  "robot_description_planning.joint_limits.panda_joint2.max_jerk",
  "robot_description_planning.joint_limits.panda_joint2.max_position",
  "robot_description_planning.joint_limits.panda_joint2.max_velocity",
  "robot_description_planning.joint_limits.panda_joint2.min_position",
  "robot_description_planning.joint_limits.panda_joint2.min_velocity",
  "robot_description_planning.joint_limits.panda_joint2.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_joint2.soft_upper_limit",
  "robot_description_planning.joint_limits.panda_joint3.angle_wraparound",
  "robot_description_planning.joint_limits.panda_joint3.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_joint3.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_joint3.has_effort_limits",
  "robot_description_planning.joint_limits.panda_joint3.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_joint3.has_position_limits",
  "robot_description_planning.joint_limits.panda_joint3.has_soft_limits",
  "robot_description_planning.joint_limits.panda_joint3.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_joint3.k_position",
  "robot_description_planning.joint_limits.panda_joint3.k_velocity",
  "robot_description_planning.joint_limits.panda_joint3.max_acceleration",
  "robot_description_planning.joint_limits.panda_joint3.max_effort",
  "robot_description_planning.joint_limits.panda_joint3.max_jerk",
  "robot_description_planning.joint_limits.panda_joint3.max_position",
  "robot_description_planning.joint_limits.panda_joint3.max_velocity",
  "robot_description_planning.joint_limits.panda_joint3.min_position",
  "robot_description_planning.joint_limits.panda_joint3.min_velocity",
  "robot_description_planning.joint_limits.panda_joint3.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_joint3.soft_upper_limit",
  "robot_description_planning.joint_limits.panda_joint4.angle_wraparound",
  "robot_description_planning.joint_limits.panda_joint4.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_joint4.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_joint4.has_effort_limits",
  "robot_description_planning.joint_limits.panda_joint4.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_joint4.has_position_limits",
  "robot_description_planning.joint_limits.panda_joint4.has_soft_limits",
  "robot_description_planning.joint_limits.panda_joint4.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_joint4.k_position",
  "robot_description_planning.joint_limits.panda_joint4.k_velocity",
  "robot_description_planning.joint_limits.panda_joint4.max_acceleration",
  "robot_description_planning.joint_limits.panda_joint4.max_effort",
  "robot_description_planning.joint_limits.panda_joint4.max_jerk",
  "robot_description_planning.joint_limits.panda_joint4.max_position",
  "robot_description_planning.joint_limits.panda_joint4.max_velocity",
  "robot_description_planning.joint_limits.panda_joint4.min_position",
  "robot_description_planning.joint_limits.panda_joint4.min_velocity",
  "robot_description_planning.joint_limits.panda_joint4.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_joint4.soft_upper_limit",
  "robot_description_planning.joint_limits.panda_joint5.angle_wraparound",
  "robot_description_planning.joint_limits.panda_joint5.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_joint5.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_joint5.has_effort_limits",
  "robot_description_planning.joint_limits.panda_joint5.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_joint5.has_position_limits",
  "robot_description_planning.joint_limits.panda_joint5.has_soft_limits",
  "robot_description_planning.joint_limits.panda_joint5.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_joint5.k_position",
  "robot_description_planning.joint_limits.panda_joint5.k_velocity",
  "robot_description_planning.joint_limits.panda_joint5.max_acceleration",
  "robot_description_planning.joint_limits.panda_joint5.max_effort",
  "robot_description_planning.joint_limits.panda_joint5.max_jerk",
  "robot_description_planning.joint_limits.panda_joint5.max_position",
  "robot_description_planning.joint_limits.panda_joint5.max_velocity",
  "robot_description_planning.joint_limits.panda_joint5.min_position",
  "robot_description_planning.joint_limits.panda_joint5.min_velocity",
  "robot_description_planning.joint_limits.panda_joint5.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_joint5.soft_upper_limit",
  "robot_description_planning.joint_limits.panda_joint6.angle_wraparound",
  "robot_description_planning.joint_limits.panda_joint6.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_joint6.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_joint6.has_effort_limits",
  "robot_description_planning.joint_limits.panda_joint6.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_joint6.has_position_limits",
  "robot_description_planning.joint_limits.panda_joint6.has_soft_limits",
  "robot_description_planning.joint_limits.panda_joint6.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_joint6.k_position",
  "robot_description_planning.joint_limits.panda_joint6.k_velocity",
  "robot_description_planning.joint_limits.panda_joint6.max_acceleration",
  "robot_description_planning.joint_limits.panda_joint6.max_effort",
  "robot_description_planning.joint_limits.panda_joint6.max_jerk",
  "robot_description_planning.joint_limits.panda_joint6.max_position",
  "robot_description_planning.joint_limits.panda_joint6.max_velocity",
  "robot_description_planning.joint_limits.panda_joint6.min_position",
  "robot_description_planning.joint_limits.panda_joint6.min_velocity",
  "robot_description_planning.joint_limits.panda_joint6.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_joint6.soft_upper_limit",
  "robot_description_planning.joint_limits.panda_joint7.angle_wraparound",
  "robot_description_planning.joint_limits.panda_joint7.has_acceleration_limits",
  "robot_description_planning.joint_limits.panda_joint7.has_deceleration_limits",
  "robot_description_planning.joint_limits.panda_joint7.has_effort_limits",
  "robot_description_planning.joint_limits.panda_joint7.has_jerk_limits",
  "robot_description_planning.joint_limits.panda_joint7.has_position_limits",
  "robot_description_planning.joint_limits.panda_joint7.has_soft_limits",
  "robot_description_planning.joint_limits.panda_joint7.has_velocity_limits",
  "robot_description_planning.joint_limits.panda_joint7.k_position",
  "robot_description_planning.joint_limits.panda_joint7.k_velocity",
  "robot_description_planning.joint_limits.panda_joint7.max_acceleration",
  "robot_description_planning.joint_limits.panda_joint7.max_effort",
  "robot_description_planning.joint_limits.panda_joint7.max_jerk",
  "robot_description_planning.joint_limits.panda_joint7.max_position",
  "robot_description_planning.joint_limits.panda_joint7.max_velocity",
  "robot_description_planning.joint_limits.panda_joint7.min_position",
  "robot_description_planning.joint_limits.panda_joint7.min_velocity",
  "robot_description_planning.joint_limits.panda_joint7.soft_lower_limit",
  "robot_description_planning.joint_limits.panda_joint7.soft_upper_limit",
  "robot_description_planning.joint_limits.virtual_joint.angle_wraparound",
  "robot_description_planning.joint_limits.virtual_joint.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint.has_deceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint.has_effort_limits",
  "robot_description_planning.joint_limits.virtual_joint.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint.has_position_limits",
  "robot_description_planning.joint_limits.virtual_joint.has_soft_limits",
  "robot_description_planning.joint_limits.virtual_joint.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint.k_position",
  "robot_description_planning.joint_limits.virtual_joint.k_velocity",
  "robot_description_planning.joint_limits.virtual_joint.max_acceleration",
  "robot_description_planning.joint_limits.virtual_joint.max_effort",
  "robot_description_planning.joint_limits.virtual_joint.max_jerk",
  "robot_description_planning.joint_limits.virtual_joint.max_position",
  "robot_description_planning.joint_limits.virtual_joint.max_velocity",
  "robot_description_planning.joint_limits.virtual_joint.min_position",
  "robot_description_planning.joint_limits.virtual_joint.min_velocity",
  "robot_description_planning.joint_limits.virtual_joint.soft_lower_limit",
  "robot_description_planning.joint_limits.virtual_joint.soft_upper_limit",
  "robot_description_planning.joint_limits.virtual_joint/rot_w.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_w.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_w.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_w.max_position",
  "robot_description_planning.joint_limits.virtual_joint/rot_w.min_position",
  "robot_description_planning.joint_limits.virtual_joint/rot_x.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_x.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_x.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_x.max_position",
  "robot_description_planning.joint_limits.virtual_joint/rot_x.min_position",
  "robot_description_planning.joint_limits.virtual_joint/rot_y.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_y.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_y.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_y.max_position",
  "robot_description_planning.joint_limits.virtual_joint/rot_y.min_position",
  "robot_description_planning.joint_limits.virtual_joint/rot_z.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_z.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_z.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint/rot_z.max_position",
  "robot_description_planning.joint_limits.virtual_joint/rot_z.min_position",
  "robot_description_planning.joint_limits.virtual_joint/trans_x.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_x.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_x.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_x.max_position",
  "robot_description_planning.joint_limits.virtual_joint/trans_x.min_position",
  "robot_description_planning.joint_limits.virtual_joint/trans_y.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_y.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_y.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_y.max_position",
  "robot_description_planning.joint_limits.virtual_joint/trans_y.min_position",
  "robot_description_planning.joint_limits.virtual_joint/trans_z.has_acceleration_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_z.has_jerk_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_z.has_velocity_limits",
  "robot_description_planning.joint_limits.virtual_joint/trans_z.max_position",
  "robot_description_planning.joint_limits.virtual_joint/trans_z.min_position",
  "robot_description_semantic",
  "stomp.control_cost_weight",
  "stomp.default_workspace_bounds",
  "stomp.delta_t",
  "stomp.display_contacts_topic",
  "stomp.display_path_topic",
  "stomp.exponentiated_cost_sensitivity",
  "stomp.fix_start_state",
  "stomp.max_rollouts",
  "stomp.num_iterations",
  "stomp.num_iterations_after_valid",
  "stomp.num_rollouts",
  "stomp.num_timesteps",
  "stomp.path_marker_topic",
  "stomp.planning_plugins",
  "stomp.progress_topic",
  "stomp.request_adapters",
  "stomp.response_adapters",
  "stomp.stomp_moveit.control_cost_weight",
  "stomp.stomp_moveit.delta_t",
  "stomp.stomp_moveit.exponentiated_cost_sensitivity",
  "stomp.stomp_moveit.max_rollouts",
  "stomp.stomp_moveit.num_iterations",
  "stomp.stomp_moveit.num_iterations_after_valid",
  "stomp.stomp_moveit.num_rollouts",
  "stomp.stomp_moveit.num_timesteps",
  "stomp.totg.min_angle_change",
  "stomp.totg.path_tolerance",
  "stomp.totg.resample_dt",
  "trajectory_execution.allowed_execution_duration_scaling",
  "trajectory_execution.allowed_goal_duration_margin",
  "trajectory_execution.allowed_start_tolerance",
  "use_sim_time",
};
}  // namespace move_group_test
